@@ -160,10 +160,25 @@ class ClickhouseCubeBackend(CubeBackend):
 
             if cols_to_add:
                 logger.debug(f"Adding columns {cols_to_add} to table '{table_name}'")
-                for col in cols_to_add:
-                    dim = cube._dimensions.get(col) or cube._metrics.get(col)
-                    spec = self._dim_spec(dim)
-                    client.execute(f"ALTER TABLE {self.database}.{table_name} ADD COLUMN {spec}")
+                # we add columns in a way that preserves the order of the columns in the definition
+                last_col = None
+                logger.debug("Cube dimensions: %s", cube._dimensions)
+                for name, dim in cube._dimensions.items():
+                    if name in cols_to_add:
+                        spec = self._dim_spec(dim)
+                        pos = f"AFTER {last_col}" if last_col else "FIRST"
+                        client.execute(
+                            f"ALTER TABLE {self.database}.{table_name} ADD COLUMN {spec} {pos}"
+                        )
+                    last_col = name
+                for name, metric in cube._metrics.items():
+                    if name in cols_to_add:
+                        spec = self._dim_spec(metric)
+                        pos = f"AFTER {last_col}" if last_col else "FIRST"
+                        client.execute(
+                            f"ALTER TABLE {self.database}.{table_name} ADD COLUMN {spec} {pos}"
+                        )
+                    last_col = name
                 changed = True
             return changed, cols_to_add, cols_to_remove
 
